@@ -61,11 +61,13 @@ class ORDER_TYPES(Enum):
 class SIDE(Enum):
     SIDE_BUY = 'BUY'
     SIDE_SELL = 'SELL'
+
+
 @unique
 class TypePosition(Enum):
     ShortMarket = '1'
     ShortLimit = '2'
-    LongMarket= '3'
+    LongMarket = '3'
     LongLimit = '4'
 
 
@@ -93,22 +95,26 @@ class Order:
 
     Label: str
     Profit: float
-    EntryPrice: float
     FilledPrice: float
     Quantity: float
     StopLoss: float
     TeikProfit: float
     Id_stop_loss_order: int
     Id_take_profit_order: int
-    UnixDataInput: int
-    UnixDataOutput: int
-
+    UnixDataStopLoss: int
+    UnixDataTeikProfit: int
+    UnixDataClose: int
 
 
 @dataclass
 class Position:
-    Type:TypePosition
+    Type: TypePosition
     Asset: Assets
+    EntryPrice: float
+    Id_entry_price: int
+    UnixDataStart: int
+    UnixDataInput: int
+    UnixDataOutput: int
     Name: str
     Orders: List[Order]
 
